@@ -7,7 +7,7 @@ from datamemorys.core import SYCM_DATAS
 import time
 class DMDataFrame(DataFrame):
     def __init__(self,DM_tablename="",loginnNickName="",data=None,index=None,columns=None,dtype=None,copy=False,**args):
-        if DM_tablename=="" and loginnNickName=="" and len(data.keys())>0:
+        if DM_tablename=="" and loginnNickName=="" and  len(data)>0:
             super().__init__(data,index,columns,dtype,copy)            
         else:
             loginnNickName=loginnNickName.split(":")[0]
